import { InjectionToken, Injectable, Inject, NgModule } from '@angular/core';
import { fromEvent } from 'rxjs';
import { take } from 'rxjs/operators';
import { io } from 'socket.io-client';

const SOCKETIO_CONFIG = new InjectionToken('SocketioConfig');

class Socketio {
    constructor({ url, options }) {
        this.socket = io(url, options);
    }
    /**
     * @see {@link Socket.id}
     */
    get id() { return this.socket.id; }
    ;
    /**
     * @see {@link Socket.connected}
     */
    get connected() { return this.socket.connected; }
    ;
    /**
     * @see {@link Socket.disconnected}
     */
    get disconnected() { return this.socket.disconnected; }
    ;
    /**
     * @see {@link Socket.io}
     */
    get io() { return this.socket.io; }
    ;
    /**
     * @see {@link Socket.auth}
     */
    get auth() { return this.socket.auth; }
    ;
    set auth(auth) { this.socket.auth = auth; }
    ;
    ngOnDestroy() {
        this.socket.offAny();
    }
    /**
     * @see {@link Socket.connect}
     */
    connect() {
        this.socket.connect();
        return this;
    }
    /**
     * @see {@link Socket.disconnect}
     */
    disconnect() {
        this.socket.disconnect();
        return this;
    }
    /**
     * @see {@link Socket.send}
     */
    send(...args) {
        this.socket.send(...args);
        return this;
    }
    /**
     * @see {@link Socket.emit}
     */
    emit(eventName, ...args) {
        this.socket.emit(eventName, ...args);
        return this;
    }
    /**
     * @see {@link Socket.on}
     */
    on(eventName) {
        return fromEvent(this.socket, eventName);
    }
    /**
     * @see {@link Socket.once}
     */
    once(eventName) {
        return this.on(eventName).pipe(take(1));
    }
    /**
     * @see {@link Socket.compress}
     */
    compress(compress) {
        this.socket.compress(compress);
        return this;
    }
}
Socketio.decorators = [
    { type: Injectable }
];
Socketio.ctorParameters = () => [
    { type: undefined, decorators: [{ type: Inject, args: [SOCKETIO_CONFIG,] }] }
];

class SocketioModule {
    static forRoot(config = { url: '' }) {
        return {
            ngModule: SocketioModule,
            providers: [
                { provide: SOCKETIO_CONFIG, useValue: config },
                { provide: Socketio, useClass: Socketio },
            ],
        };
    }
}
SocketioModule.decorators = [
    { type: NgModule }
];

/*
 * Public API Surface of ngx-socketio2
 */

/**
 * Generated bundle index. Do not edit.
 */

export { Socketio, SocketioModule, SOCKETIO_CONFIG as ɵa };
//# sourceMappingURL=ngx-socketio2.js.map
